drsDistributions

Description
This is a python package that operates distributions of probabilities.

Files
Binomialdistribution.py -> a file containing the class to deal with the binomial distribution.
Gaussiandistribution.py -> a file containing the class to deal with the normal distribution.
Generaldistribution.py -> a file containing the class to deal with the a general distribution, all the prior files inherit the class in this file.

Instalation
pip install drsDistributions